'subroutine that makes an equation output table.

'inputs:
'  tab  		table object (note this table object must already exist)
'  !row		row at which to start the output  (usually 1).   On exit will be set at final row number
'  coefs		coefficient vector
'  cov		covariance sym matrix
'  %coefnames  coefficient names
'  %title		equation title (if null, equation title won't be added (and nor will date/time)
' %method	equation method (if null, equation method won't be added) 
'  %sample  sample string (if null, sample string won't be added)
'  %obs         string containing number of observations (if null observation count won't be added)
'  !df			Degree of Freedom correction
'  %dist		string containing name of distribution function to use for p-values.  (If null, it will use @tdist (i.e. t-distribution))

subroutine local maketable(table tab, scalar !row, vector coefs, sym cov, string %coefnames, string %title, string %method, string %sample, string %obs, scalar !df, string %dist)
	'check sizes are ok
	if @rows(coefs) <> @rows(cov) then
		seterr "Coefficient vector not comparable with covariance matrix"
		return
	endif
	if @rows(coefs) <> @wcount(%coefnames) then
		seterr "Coefficient names not comparable with coefficient vector"
		return
	endif
	
	tab.setwidth(1) 19   'set column width for first column
	tab.setwidth(2) 10	
	tab.setwidth(3:4) 11
	tab.setwidth(5) 9
	if @len(%title) then  'add title and date/time
		tab(!row,1) = %title
		tab.setjust(!row,1) left
		!row = !row + 1
	endif
	if @len(%method) then   'add method string
		%meth = "Method: " + %method
		tab(!row,1) = %meth
		tab.setjust(!row,1) left
		!row = !row + 1
	endif
	if @len(%title) then    	'add date and time
		%datestring = "Date: " + @datestr(@now,"MM/DD/YY") + "   Time: " + @datestr(@now,"HH:MM")
		tab(!row,1) = %datestring
		tab.setjust(!row,1) left
		!row = !row + 1				
	endif
	if @len(%sample) then   'add sample string
		%smpl = "Sample: " + %sample
		tab(!row,1) = %smpl
		tab.setjust(!row,1) left
		!row = !row + 1
	endif
	if @len(%obs) then   'add number of observations
		%ob = "Included observations: " + %obs
		tab(!row,1) = %ob
		tab.setjust(!row,1) left
		!row = !row+1
	endif
	tab.setlines(!row, a, !row, e) +d
	!row = !row+1
	
	'add coefficient column headings
	tab(!row,1) = "Variable"
	tab(!row,2) = "Coefficient"
	tab(!row,3) = "Std. Error"
	tab(!row,4) = "t-Statistic"
	tab(!row,5) = "Prob.  "
	tab.setjust(!row, 2, !row, 5) right
	!row = !row + 1
	tab.setlines(!row) +d
	!row = !row+1
	
	'row headings
	!temprow = !row
	for !i = 1 to @wcount(%coefnames)
		tab(!temprow,1) = @upper(@word(%coefnames,!i))
		!temprow = !temprow+1
	next
	
	
	'coefficients etc..
	if @len(%dist) = 0 then
		%dist = "@tdist"
	endif
	for !i=1 to @wcount(%coefnames)  
		!coef = coefs(!i)
		!covar = @sqrt(cov(!i,!i))
		!tstat = !coef/!covar
		!pvalue = {%dist}(!tstat,!df)
		tab(!row ,2) = !coef
		tab(!row,3) = !covar
		tab(!row,4) = !tstat
		tab(!row,5) = !pvalue
		tab.setformat(!row,5) "f.4"
		tab.setjust(!row, 2, !row, 5) right
		!row = !row + 1
	next
	tab.setlines(!row) +d
	!row=  !row+1
		
endsub
